@@ -8,7 +8,7 @@ from rdr import *
 @click.argument( 'carrel', metavar='<carrel>' )
 def sql( carrel ) :
 
-	"""Use SQL queries against the database of <carrel>
+	"""Use SQL queries against the database of <carrel>.
 	
 	Study carrels are made up of many files. One of those files is an SQLite database file (etc/reader.db). Use this subcommand to query the database. Because the database is relational in design, the use of SQL can draw information from many different tables and address almost any question about <carrel>. An excellent query that an be applied to any carrel includes:
 	
